WhooshES
========

.. image:: https://img.shields.io/pypi/v/whooshes.svg
   :target: https://pypi.python.org/pypi/whooshes
   :alt: PyPI

.. image:: https://img.shields.io/badge/license-MIT-red.svg
   :target: https://en.wikipedia.org/wiki/MIT_License
   :alt: Licence - MIT

.. image:: https://github.com/aiudirog/whooshes/workflows/tests/badge.svg
   :target: https://github.com/aiudirog/whooshes
   :alt: Tests Status

.. image:: https://readthedocs.org/projects/whooshes/badge/?version=latest
   :target: https://whooshes.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://codecov.io/gh/aiudirog/whooshes/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/aiudirog/whooshes
   :alt: Coverage Status

WhooshES is a toolkit for working with
`Whoosh <https://github.com/whoosh-community/whoosh>`__ and
`Elasticsearch <https://github.com/elastic/elasticsearch>`__ using a standard
API.

Installation
------------

This package can be installed from the official PyPI:

.. code-block:: sh

    $ pip install whooshes

Documentation
-------------

The documentation can be found on `Read the Docs
<https://whooshes.readthedocs.io/en/latest/>`__.
